@@ -687,7 +687,7 @@ void on_play_clicked(GtkButton *button, gpointer user_data) {
 
 	if (config_log) {
 		gtmp = g_strconcat(grsync_dir, "/", groups[session_last], ".log", NULL);
-		log_file = fopen(gtmp, "w");
+		log_file = fopen(gtmp, "a");
 		g_free(gtmp);
 	}
 
@@ -918,6 +918,7 @@ void rsync_cleanup(gpointer data) {
 	if (more || (cmdline_execute && !(config_errorlist && had_error) && !cmdline_stayopen)) on_close_clicked(NULL, NULL);
 
 	if (log_file != NULL) {
+		fputs("\n", log_file);
 		fclose(log_file);
 		log_file = NULL;
 	}
@@ -1076,6 +1077,7 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 	GtkWidget *error;
 	gchar *comm_str, *comm_text, *comm_out, *comm_err, *comm_before, *tmpc;
 	gboolean halt = FALSE;
+	time_t rawtime;
 
 	rsync_pid = 0;
 	if (!is_set || first) had_error = FALSE;
@@ -1101,11 +1103,16 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 		if (dryrunning) tmpc =_("** Launching RSYNC command (simulation mode):\n");
 		else tmpc = _("** Launching RSYNC command:\n");
 	}
-	comm_text = g_strconcat("**** ", groups[session_last], "\n\n", comm_before, tmpc, comm_str, "\n\n", NULL);
+	time(&rawtime);
+	comm_text = g_strconcat("**** ", groups[session_last], " - ", ctime(&rawtime), "\n", comm_before, tmpc, comm_str, "\n\n", NULL);
 	g_free(comm_before);
 	g_free(comm_str);
 
 	view = (GtkTextView*)gtk_builder_get_object(builder, "textview_output");
+	PangoFontDescription *font_desc = pango_font_description_from_string("monospace 10");
+	gtk_widget_modify_font((GtkWidget*) view, font_desc);
+	pango_font_description_free(font_desc);
+
 	buffer = gtk_text_view_get_buffer(view);
 	if (is_set && !first) gtk_text_buffer_insert_at_cursor(buffer, "\n", -1);
 	else gtk_text_buffer_set_text(buffer, "", -1);
